@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {- |
 Module      :  Control.Monad.Error.Class
 Copyright   :  (c) Michael Weber <michael.weber@post.rwth-aachen.de> 2001,
@@ -51,8 +52,9 @@ import Control.Monad.Trans.Writer.Strict as StrictWriter
 import Control.Monad.Trans
 
 import qualified Control.Exception
-import Control.Monad
-import Control.Monad.Instances ()
+#if !(MIN_VERSION_base(4,6,0))
+import Control.Monad.Instances ()  -- deprecated from base-4.6
+#endif
 import Data.Monoid
 import System.IO
 
