@@ -4,9 +4,9 @@ Copyright   :  (c) Andy Gill 2001,
                (c) Oregon Graduate Institute of Science and Technology 2001,
                (c) Jeff Newbern 2003-2006,
                (c) Andriy Palamarchuk 2006
-License     :  BSD-style (see the file libraries/base/LICENSE)
+License     :  BSD-style (see the file LICENSE)
 
-Maintainer  :  libraries@haskell.org
+Maintainer  :  ross@soi.city.ac.uk
 Stability   :  experimental
 Portability :  portable
 
